@@ -1,6 +1,8 @@
 from typing import Type, Dict, List
+from contextlib import contextmanager
+from copy import deepcopy
 
-from .interfaces import IMessenger
+from .interfaces import IApos
 from .interfaces import IEvent
 from .interfaces import ICommand
 from .interfaces import IQuery
@@ -12,7 +14,7 @@ from .exceptions import MissingHandler
 from .exceptions import OverwritingHandler
 
 
-class Messenger(IMessenger):
+class Apos(IApos):
 
     def __init__(self) -> None:
         self._command_handlers: Dict[str, ICommandHandler] = dict()
@@ -20,6 +22,15 @@ class Messenger(IMessenger):
         self._query_handlers: Dict[str, IQueryHandler] = dict()
         self._published_events: List[IEvent] = list()
 
+    @contextmanager
+    def session(self):
+        published_events_bkp = deepcopy(self._published_events)
+        self._published_events = list()
+        try:
+            yield self
+        finally:
+            self._published_events = published_events_bkp
+
     def get_published_events(self) -> List[IEvent]:
         return self._published_events
 
